@@ -188,10 +188,12 @@ Email - mrfrozenpeak@gmail.com
 
 import numpy as np
 import matplotlib.pyplot as plt
-from sklearn import datasets
-from sklearn.model_selection import  train_test_split
-from sklearn.manifold import TSNE
-from frozenSpider import Data_visualisation as dv
+from frozenSpider import spiderAlgorithmResources as res
+#from sklearn import datasets
+#from sklearn.model_selection import  train_test_split
+#from frozenSpider import Data_visualisation as dv
+
+
 
 
 
@@ -325,17 +327,12 @@ class plot_model(LogisticRegression):
         self.ylabel_size = 15
         self.title_size = 18
         self.model = model
-        self.color_dict = {"Red":"#FF0000", "Orange": "#FFA500", "Yellow": "#FFFF00", "DeepPink" :"#FF1493", "LightPink":"#FFB6C1","LightPink":"#FFB6C1"
-                           ,"Pink":"#FFC0CB", "Lavender":"#E6E6FA", "Orchid":"#DA70D6", "Violet":"#EE82EE", "DarkOrchid": "#9932CC", "DarkViolet":"#9400D3"
-                           ,"BlueViolet":"#8A2BE2", "Purple":"#800080", "Purple":"#800080", "Indigo":"#4B0082", "Salmon":"#FA8072", "Crimson":"#DC143C","DarkRed":"#8B0000",
-                           "DarkOrange":"#FF8C00", "Coral":"#FF7F50","OrangeRed":"#FF4500", "Gold":"#FFD700", "GreenYellow":"#ADFF2F", "Lime":"#00FF00", "PaleGreen":"#98FB98"
-                           ,"SpringGreen":"#00FF7F", "Green":"#008000", "LightSeaGreen":"#20B2AA", "Cyan":"#00FFFF", "Aquamarine":"#7FFFD4", "SkyBlue":"#87CEEB",
-                           "DeepSkyBlue":"#00BFFF", "Blue":"#0000FF", "MediumBlue":"#0000CD", "Navy":"#000080", "Black":"#000000", "Gray":"#808080"}
+        self.color_dict = res.Resources.get_color_dict()
         self.calculated_point_size = 10
         self.calculated_point_class0_label = "Calculated class 0"
         self.calculated_point_class1_label = "Calculated class 1"
-        self.calculated_point_class0_color = "Red"
-        self.calculated_point_class1_color = "Cyan"
+        self.calculated_point_class0_color = "red"
+        self.calculated_point_class1_color = "cyan"
         self.calculated_point_alpha = 0.5
 
 
@@ -368,7 +365,22 @@ class plot_model(LogisticRegression):
 
     #function to set vlues for title, x/y label and values of labels in case.........................
 
-    def set_marker_properties(self, label_default=True, calculated_point_class1_label = "Calculated class 1", calculated_point_class0_label="Calculated class 0", calculated_point_alpha = 0.5,  calculated_point_class1_color='Red',calculated_point_class0_color="Cyan", title_size=15, xlabel_size=10, ylabel_size=10, title="Output vs dimention", y_label="y coordinates", title_color="#FF0000", xlabel_color="#663399", ylabel_color="#663399"):
+    def set_marker_properties(self,
+                              label_default=True,
+                              calculated_point_class1_label = "Calculated class 1",
+                              calculated_point_class0_label="Calculated class 0",
+                              calculated_point_alpha = 0.5,
+                              calculated_point_class1_color='red'
+                              ,calculated_point_class0_color="cyan",
+                              title_size=15, xlabel_size=10,
+                              ylabel_size=10, title="Output vs dimention",
+                              y_label="y coordinates",
+                              title_color="#FF0000",
+                              xlabel_color="#663399",
+                              ylabel_color="#663399"):
+
+
+
         self.title_size = title_size
         self.xlabel_size = xlabel_size
         self.ylabel_size = ylabel_size
@@ -418,7 +430,16 @@ class plot_model(LogisticRegression):
 
 
 
-    def plot_model(self, display_graph = True,display_calculated_points = True, alpha=0.6, point_size=25,label_x=[], label_y=[],class1_color='Purple', class0_color='Orange',unknown_points_label="Unknown points",line_label='Best Fit line', point_color='DeepSkyBlue', save_fig_file='dont'):
+    def plot_model(self,
+                   display_graph = True,
+                   display_calculated_points = True,
+                   alpha=0.6, point_size=25,label_x=[], label_y=[],
+                   class1_color='purple',
+                   class0_color='orange',
+                   unknown_points_label="Unknown points",
+                   line_label='Best Fit line',
+                   point_color='DeepSkyBlue',
+                   save_fig_file='dont'):
 
 
         # These are the coordinates to plot the line which is inclusion of both known and calculated points
@@ -478,9 +499,15 @@ class plot_model(LogisticRegression):
 
 
 
-            plt.title(self.title, fontdict={"fontsize": 15}, color=self.title_color)
-            plt.xlabel(self.x_label[dimention], fontdict={"fontsize": 15}, color=self.xlabel_color)
-            plt.ylabel(self.y_label, fontdict={"fontsize": 15}, color=self.ylabel_color)
+            plt.title(self.title,
+                      fontdict=res.Resources.title_dict,
+                      color=self.title_color)
+            plt.xlabel(self.x_label[dimention],
+                       fontdict=res.Resources.label_dict,
+                       color=self.xlabel_color)
+            plt.ylabel(self.y_label,
+                       fontdict=res.Resources.label_dict,
+                       color=self.ylabel_color)
 
 
 
@@ -576,7 +603,17 @@ plot.plot_model(save_fig_file="./sample_graphs", display_graph=False)
 
 """
 datav = dv.Logistic_regression_plot(lor)
-datav.plot_3D_visuals(plot_test_data=True)
+datav.plot_3D_visuals(plot_test_data=True, save_fig_path="./sample_graphs")
+"""
+
+
+
+#Exampl2 extention. How to plot a T-sne 2D graph using above Logrithmic regression
+
+"""
+datav = dv.Logistic_regression_plot2D(lor)
+datav.plot_2D_visuals(plot_test_data=True, save_fig_path="./sample_graphs")
+
 """
 
 
@@ -586,8 +623,3 @@ datav.plot_3D_visuals(plot_test_data=True)
 
 
 
-
-
-
-
-
